# TaskLoop

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**brand** | **str** |  | [optional] 
**builtin_condition** | [**list[ArgFilter]**](ArgFilter.md) |  | [optional] 
**exit_condition** | **str** |  | [optional] 
**for_each** | **bool** |  | [optional] 
**is_command** | **bool** |  | [optional] 
**script_arguments** | [**dict(str, AdvanceArg)**](AdvanceArg.md) |  | [optional] 
**script_id** | **str** |  | [optional] 
**wait** | **int** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


